@@ -1,7 +1,7 @@
 package Carton;
 use strict;
 use 5.008_005;
-use version; our $VERSION = version->declare("v1.0.9");
+use version; our $VERSION = version->declare("v1.0.10");
 
 1;
 __END__
@@ -14,8 +14,8 @@ Carton - Perl module dependency manager (aka Bundler for Perl)
 
   # On your development environment
   > cat cpanfile
-  requires 'Plack', 0.9980;
-  requires 'Starman', 0.2000;
+  requires 'Plack', '0.9980';
+  requires 'Starman', '0.2000';
 
   > carton install
   > git add cpanfile cpanfile.snapshot
@@ -44,6 +44,8 @@ I<cpanfile.snapshot> file, which is meant to be version controlled,
 and the snapshot file allows other developers of your application will
 have the exact same versions of the modules.
 
+For C<cpanfile> syntax, see L<cpanfile> documentation.
+
 =head1 TUTORIAL
 
 =head2 Initializing the environment
@@ -53,7 +55,7 @@ recommended to exclude these directories from the version control
 system.
 
   > echo local/ >> .gitignore
-  > git add cpanfile.snapshot
+  > git add cpanfile cpanfile.snapshot
   > git commit -m "Start using carton"
 
 =head2 Tracking the dependencies
@@ -61,8 +63,8 @@ system.
 You can manage the dependencies of your application via C<cpanfile>.
 
   # cpanfile
-  requires 'Plack', 0.9980;
-  requires 'Starman', 0.2000;
+  requires 'Plack', '0.9980';
+  requires 'Starman', '0.2000';
 
 And then you can install these dependencies via:
 
@@ -72,10 +74,11 @@ The modules are installed into your I<local> directory, and the
 dependencies tree and version information are analyzed and saved into
 I<cpanfile.snapshot> in your directory.
 
-Make sure you add I<cpanfile.snapshot> to your version controlled repository
-and commit changes as you update dependencies. This will ensure that
-other developers on your app, as well as your deployment environment,
-use exactly the same versions of the modules you just installed.
+Make sure you add I<cpanfile> and I<cpanfile.snapshot> to your version
+controlled repository and commit changes as you update
+dependencies. This will ensure that other developers on your app, as
+well as your deployment environment, use exactly the same versions of
+the modules you just installed.
 
   > git add cpanfile cpanfile.snapshot
   > git commit -m "Added Plack and Starman"
@@ -161,6 +164,8 @@ This software is licensed under the same terms as Perl itself.
 
 L<cpanm>
 
+L<cpanfile>
+
 L<Bundler|http://gembundler.com/>
 
 L<pip|http://pypi.python.org/pypi/pip>
